@@ -12,6 +12,7 @@ import functools
 import itertools
 import json
 import types
+import typing
 from typing import Any, TypeVar, Union, Callable, Optional
 
 from .is_instance import get_container_type, is_instance
@@ -53,6 +54,8 @@ def to_datetime(value: Union[str, int, float]) -> datetime.datetime:
         return datetime.datetime.fromisoformat(value)
     return datetime.datetime.fromtimestamp(value)
 
+def pass_value(value: Any) -> Any:
+    return value
 
 @functools.cache
 def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callable[[Any], Any]:
@@ -64,6 +67,8 @@ def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callabl
         converter = type_
         if type_ == bool:
             converter = to_bool
+        if type_ == typing.Any:
+            converter = pass_value
         if type_ == datetime.time:
             converter = datetime.time.fromisoformat
         if type_ == datetime.date:
