@@ -96,7 +96,7 @@ def is_instance(
                 return True
         else:
             container_type = get_container_type(type_origin)
-            if not isinstance(val, container_type):
+            if container_type is None or not isinstance(val, container_type):
                 continue
 
             if issubclass(container_type, collections.abc.Mapping):
